@@ -4,11 +4,14 @@ import numpy as np
 
 class homework_three():
     def __init__(self, stdID):
-        # Check if Student-ID is an integer or if the function is to be run in "test-mode"
-        if type(stdID) == int:
-            self.stdID = stdID
-        elif stdID == "test":
+        # Check if Student-ID is an integer and if the function is to be run in "test-mode"
+        
+        #'TEst-Mode' is activated by the Std-ID input: 123456789
+        # For this to be viable, 123456789 CANNEVER be a viable student-id
+        if type(stdID) == int and stdID == 123456789:
             self.stdID = "testing"
+        elif type(stdID) == int and stdID != 123456789:
+            self.stdID = stdID
         else:
             print("Student ID required to be an integer.\nPlease try again!\n\n")
             pass
@@ -50,8 +53,10 @@ class homework_three():
     # counter is an integer used to define how many rngs are created.
         #print("Matriculation-Number accepted.\n\nGenerating random numbers..")
         #print("Matriculation-Number accepted.\n\nGenerating personalized homework parameters..")
-        if self.stdID == "test":
-            print("Test not implmented yet")
+        if self.stdID == "testing":
+            print("#####\n\nTesting functionality\n\n#####")
+            print("#####\n\The Std-ID is not a valid Student-ID\n and CAN'T generate a valid code!\n\n#####")
+            # NOTE: no self.listofrndms is created in test mode
         else:
         #RNG for this homework
             rd.seed(self.stdID)
@@ -103,27 +108,28 @@ class homework_three():
         #    -> randomint
         # YZ: Summ(studentID[0]+studentID[1]) <10 OR >= 10:
         #    -> 2x randomint
-        try:
-            if type(self.stdID) == int:
-                stdIDstr = str(self.stdID)
-            if self.stdID == "testing":
-                with self.question_one_display.children[0]:
-                    print('\nTesting solution calculation...\n')
-                    Yxc = self.newYxs - 1
-                    print("\nYxc:",Yxc)
-                    Yxn = self.newN
-                    Yxw = (self.newYxs*2 + Yxn*3 - self.newH)/2
-                    print("\nYxw:",Yxw)
-                    Yxo = (-self.newYxs + Yxw + 2*Yxc + self.newO)/2
-                    print("\nYxo:",Yxo)
+        if self.stdID == "testing":
+            with self.question_one_display.children[0]:
+                print('\nTesting solution calculation...\n')
+                print("#####\n\nThe Std-ID is not a valid Student-ID\n and CAN'T generate a valid code!\n\n#####")
 
-                    realRQ = Yxc/Yxo
-                    print("\nrealRQ:",realRQ)
-        except:
-            print("This message should not occur, did you change anything? Please check if your solution is in the right format!")
+                Yxc = self.newYxs - 1
+                print("\nYxc:",Yxc)
+                Yxn = self.newN
+                Yxw = (self.newYxs*2 + Yxn*3 - self.newH)/2
+                print("\nYxw:",Yxw)
+                Yxo = (-self.newYxs + Yxw + 2*Yxc + self.newO)/2
+                print("\nYxo:",Yxo)
 
-        #Calculation of the solution:
-        try:
+                realRQ = Yxc/Yxo
+                print("\nrealRQ:",realRQ)        
+        
+        
+        if type(self.stdID) == int:
+            stdIDstr = str(self.stdID)
+
+
+            #Calculation of the solution:
             with self.question_one_display.children[-1]:
 
                 Yxc = self.newYxs - 1
@@ -141,6 +147,7 @@ class homework_three():
                 #Assumes aswer was rounded to 2 decimals
                 if round(realRQ,2) == RQ:
                     self.question_one_display.children[-3].children[0].disabled = True
+                    self.question_one_display.children[-3].children[1].disabled = True
                     print("Solution corect! RQ is {}".format(realRQ))
 
                     solcode = ""
@@ -151,10 +158,10 @@ class homework_three():
                     elif self.hq1tgl == 1:
                         solcode+=(str(rd.randrange(5,9)))
 
-                    if int(stdIDstr[0])+int(stdIDstr[1]) < 10:
+                    if int(stdIDstr[-1])+int(stdIDstr[-2]) < 10:
                         solcode+=(str(rd.randrange(0,4)))
                         solcode+=(str(rd.randrange(0,4)))
-                    elif int(stdIDstr[0])+int(stdIDstr[1]) >= 10:
+                    elif int(stdIDstr[-1])+int(stdIDstr[-2]) >= 10:
                         solcode+=(str(rd.randrange(5,9)))
                         solcode+=(str(rd.randrange(5,9)))    
                     # PRINT THE CODE
@@ -163,8 +170,7 @@ class homework_three():
                 #If the solution was not correct, the students can try again
                 else:
                     print("Solution WRONG!\nDon't give up and try again!")
-        except:
-            print("This message should not occur, did you change anything? Please check if your solution is in the right format!")
+
 ###############
 ###############
 ###############
@@ -181,45 +187,45 @@ class homework_three():
         #    -> randomint
         # YZ: Summ(studentID[0]+studentID[1]) <10 OR >= 10:
         #    -> 2x randomint
-        try:
-            if type(self.stdID) == int:
-                stdIDstr = str(self.stdID)
-            if self.stdID == "testing":
-                with self.question_two_display.children[0]:
-                    print('\nTesting solution calculation...\n')
 
-                    #1. Converting biomass concentration from g/l to c-mol
-                    Xn = (round(46.5/(1*12+self.newH*1+self.newO*16+self.newN*14),2)*10000) 
-                    print("\nXn:",Xn)
-                    #Xn = ((50 g/L - 7 % ash)/(masses of C_1+H_newH+O_newO+N_newN) g/mol) * 10000 L = x cmol
-                    # 12, 1, 16, and 14 are the assumed molecular masses of the specific elements
+        if self.stdID == "testing":
+            with self.question_two_display.children[0]:
+                print('\nTesting solution calculation...\n')
+                print("#####\n\nThe Std-ID is not a valid Student-ID\n and CAN'T generate a valid code!\n\n#####")
 
-                    #2. Normalizing gas exchange rates
-                    rO2 = round(self.newRO2/Xn,2)
-                    rCO2 = round(self.newRCO2/Xn,2)
-                    print("\nrO2:",rO2)
-                    print("\nrCO2:",rCO2)
 
-                    #3. Calculating Yields, YXO, YXC
-                    mu = 0.35 #Growthrate = 0.35 1/h
-                    Yxo = rO2/mu
-                    Yxc = rCO2/mu
-                    Yxn = self.newN
-                    print("\nYxo:",Yxo)
-                    print("\nYxc:",Yxc)
-                    Ymatrixvar = np.array([[2,1],[1,-0.5]])
-                    Ymatrixsolvd = np.array([-1*(self.newH-2-2*Yxc-3*Yxn), -1*(self.newO+1*Yxc-1-2*Yxo)])
-                    Ymatrix = np.linalg.solve(Ymatrixvar,Ymatrixsolvd)
-                    Yxw,Yxe = Ymatrix
-                    Yxs = Yxe+1+Yxc
-                    print("\nYxe:",Yxe)
-                    print("\nYxs:",Yxs)
-        except:
-            print("This message should not occur, did you change anything? Please check if your solution is in the right format!")
+                #1. Converting biomass concentration from g/l to c-mol
+                Xn = (round(46.5/(1*12+self.newH*1+self.newO*16+self.newN*14),2)*10000) 
+                print("\nXn:",Xn)
+                #Xn = ((50 g/L - 7 % ash)/(masses of C_1+H_newH+O_newO+N_newN) g/mol) * 10000 L = x cmol
+                # 12, 1, 16, and 14 are the assumed molecular masses of the specific elements
 
-        #Calculation of the solution:
-        try:
-             with self.question_two_display.children[-1]:
+                #2. Normalizing gas exchange rates
+                rO2 = round(self.newRO2/Xn,2)
+                rCO2 = round(self.newRCO2/Xn,2)
+                print("\nrO2:",rO2)
+                print("\nrCO2:",rCO2)
+
+                #3. Calculating Yields, YXO, YXC
+                mu = 0.35 #Growthrate = 0.35 1/h
+                Yxo = rO2/mu
+                Yxc = rCO2/mu
+                Yxn = self.newN
+                print("\nYxo:",Yxo)
+                print("\nYxc:",Yxc)
+                Ymatrixvar = np.array([[2,1],[1,-0.5]])
+                Ymatrixsolvd = np.array([-1*(self.newH-2-2*Yxc-3*Yxn), -1*(self.newO+1*Yxc-1-2*Yxo)])
+                Ymatrix = np.linalg.solve(Ymatrixvar,Ymatrixsolvd)
+                Yxw,Yxe = Ymatrix
+                Yxs = Yxe+1+Yxc
+                print("\nYxe:",Yxe)
+                print("\nYxs:",Yxs)
+
+        if type(self.stdID) == int:
+            stdIDstr = str(self.stdID)
+            
+            #Calculation of the solution:
+            with self.question_two_display.children[-1]:
 
                 #1. Converting biomass concentration from g/l to c-mol
                 Xn = (round(46.5/(1*12+self.newH*1+self.newO*16+self.newN*14),2)*10000) 
@@ -257,10 +263,10 @@ class homework_three():
                     elif self.hq2tgl == 1:
                         solcode+=(str(rd.randrange(5,9)))
 
-                    if int(stdIDstr[0])+int(stdIDstr[1]) < 10:
+                    if int(stdIDstr[-1])+int(stdIDstr[-2]) < 10:
                         solcode+=(str(rd.randrange(0,4)))
                         solcode+=(str(rd.randrange(0,4)))
-                    elif int(stdIDstr[0])+int(stdIDstr[1]) >= 10:
+                    elif int(stdIDstr[-1])+int(stdIDstr[-2]) >= 10:
                         solcode+=(str(rd.randrange(5,9)))
                         solcode+=(str(rd.randrange(5,9)))    
                     # PRINT THE CODE
@@ -275,8 +281,7 @@ class homework_three():
                     #print("Real Yxe={}\nStudent_Ethanol_Yield={}".format(Yxe,Yield_Ethanol))
                     #print("Real Yxs={}\nStudent_Substrate_Yield={}".format(Yxs,Yield_Substrate))
                     print("Solution WRONG!\nDon't give up and try again!")
-        except:
-            print("This message should not occur, did you change anything? Please check if your solution is in the right format!")    
+
     ######
     # functions that create widgets
     #
@@ -297,10 +302,11 @@ class homework_three():
         listofwidgets.append(widgets.Output(
         ))
         with listofwidgets[0]:
-            print("##########\n\nParameters for Question 1:\n\n"\
-            "Your glucose yield Y_(XS) is {} C-mol glucose/C-mol biomass\n\n"\
-            "Your biomass composition is CH_({})O_({})N_({})\n\n##########".format(self.newYxs,self.newH,self.newO,self.newN))
-        
+            #print("##########\n\nParameters for Question 1:\n\n"\
+            #"Your glucose yield Y_(XS) is {} C-mol glucose/C-mol biomass\n\n"\
+            #"Your biomass composition is CH_({})O_({})N_({})\n\n##########".format(self.newYxs,self.newH,self.newO,self.newN))
+            print("")
+            
         listofwidgets.append(widgets.FloatText(
             value=0.00,
             description='RQ:',
@@ -320,7 +326,7 @@ class homework_three():
             description='Check RQ',
             disabled=False,
             button_style='', # 'success', 'info', 'warning', 'danger' or ''
-            tooltip='Description',
+            tooltip='Click to check solution',
             #     icon='check' # (FontAwesome names without the `fa-` prefix)
         ))
                              
@@ -329,7 +335,7 @@ class homework_three():
             description='Calculation Help',
             disabled=False,
             button_style='', # 'success', 'info', 'warning', 'danger' or ''
-            tooltip='Description',
+            tooltip='Click to get a tipp',
         #     icon='check' # (FontAwesome names without the `fa-` prefix)
         ))
                  
@@ -357,10 +363,11 @@ class homework_three():
             listofwidgets.append(widgets.Output(
             ))
             with listofwidgets[0]:
-                print("##########\n\nParameters for Question 2:\n\n"\
-                "Your O_2 Exchange-Rate is {} mol/h\n\n"\
-                "Your CO_2 Exchange-Rate is {} mol/h\n\n##########".format(self.newRO2,self.newRCO2))
-
+                #print("##########\n\nParameters for Question 2:\n\n"\
+                #"Your O_2 Exchange-Rate is {} mol/h\n\n"\
+                #"Your CO_2 Exchange-Rate is {} mol/h\n\n##########".format(self.newRO2,self.newRCO2))
+                print("")
+                
             listofwidgets.append(widgets.FloatText(
                 value=0.00,
                 description='Ethanol Yield:',
@@ -387,10 +394,10 @@ class homework_three():
             i = []
             i.append(widgets.Button(
                 value=False,
-                description='Check RQ',
+                description='Check Yields',
                 disabled=False,
                 button_style='', # 'success', 'info', 'warning', 'danger' or ''
-                tooltip='Description',
+                tooltip='Click to check solution',
                 #     icon='check' # (FontAwesome names without the `fa-` prefix)
             ))
 
@@ -399,7 +406,7 @@ class homework_three():
                 description='Calculation Help',
                 disabled=False,
                 button_style='', # 'success', 'info', 'warning', 'danger' or ''
-                tooltip='Description',
+                tooltip='Click to get a tipp',
             #     icon='check' # (FontAwesome names without the `fa-` prefix)
             ))
 
@@ -422,7 +429,7 @@ class homework_three():
         self.question_one_display.children[-3].children[1].disabled = True
         with self.question_one_display.children[-2]:
             txt = "##########\n" \
-            "The RQ is rate of CO_2 production, divivided by the rate of O_2 production\n" \
+            "The RQ is rate of CO_2 production divivided by the rate of O_2 production\n" \
             "RQ = r(CO_2)/r(O_2)\n" \
             "Yields correlate directly to rates\n" \
             "RQ = r(CO_2)/r(O_2) = Y(CO_2)/Y(O_2)\n\n" \
@@ -448,4 +455,4 @@ class homework_three():
     def on_question_two_answer_button_clicked(self, click):
         student_answer_ethanol_yield = self.question_two_display.children[1].value
         student_answer_substrate_yield = self.question_two_display.children[2].value
-        self.correct_homework_three_question_two(student_answer_ethanol_yield, student_answer_substrate_yield)
\ No newline at end of file
+        self.correct_homework_three_question_two(student_answer_ethanol_yield, student_answer_substrate_yield)
